summaryrefslogtreecommitdiffstats
path: root/korganizer/koattendeeeditor.h
diff options
context:
space:
mode:
Diffstat (limited to 'korganizer/koattendeeeditor.h')
-rw-r--r--korganizer/koattendeeeditor.h6
1 files changed, 3 insertions, 3 deletions
diff --git a/korganizer/koattendeeeditor.h b/korganizer/koattendeeeditor.h
index abe64959..3454f81d 100644
--- a/korganizer/koattendeeeditor.h
+++ b/korganizer/koattendeeeditor.h
@@ -71,12 +71,12 @@ class KOAttendeeEditor : public TQWidget
void initOrganizerWidgets( TQWidget *parent, TQBoxLayout *layout );
void initEditWidgets( TQWidget *parent, TQBoxLayout *layout );
/** Reads values from a KABC::Addressee and inserts a new Attendee
* item into the listview with those items. Used when adding attendees
* from the addressbook and expanding distribution lists.
* The optional Attendee parameter can be used to pass in default values
* to be used by the new Attendee. */
- void insertAttendeeFromAddressee( const KABC::Addressee &a, const KCal::Attendee* at=0 );
+ void insertAttendeeFromAddressee( const TDEABC::Addressee &a, const KCal::Attendee* at=0 );
void fillOrganizerCombo();
virtual TQListViewItem* hasExampleAttendee() const = 0;
@@ -122,7 +122,7 @@ class KOAttendeeEditor : public TQWidget
TQPtrList<KCal::Attendee> mnewAttendees;
private:
- KABC::Addressee::List expandDistList( const TQString &text ) const;
+ TDEABC::Addressee::List expandDistList( const TQString &text ) const;
bool mDisableItemUpdate;
};
@@ -71,12 +71,12 @@ class KOAttendeeEditor : public TQWidget
void initOrganizerWidgets( TQWidget *parent, TQBoxLayout *layout );
void initEditWidgets( TQWidget *parent, TQBoxLayout *layout );
- /** Reads values from a KABC::Addressee and inserts a new Attendee
+ /** Reads values from a TDEABC::Addressee and inserts a new Attendee
* item into the listview with those items. Used when adding attendees
* from the addressbook and expanding distribution lists.